@@ -24,7 +24,7 @@ from .setup_info import SETUP_INFO
 
 __version__ = SETUP_INFO['version']
 
-intersphinx_urls = dict(docs="https://atelier.lino-framework.org")
+intersphinx_urls = dict(docs="https://lino-framework.gitlab.io/atelier")
 srcref_url = 'https://gitlab.com/lino-framework/atelier/blob/master/%s'
 # doc_trees = ['docs']
 
