@@ -5,6 +5,15 @@
 # from `setup.py`, `atelier/__init__.py` and possibly some external
 # tools, too.
 
+SETUP_INFO = dict(
+    name='atelier',
+    version='1.1.41',
+    description="A collection of tools for software artists",
+    license_files=['COPYING'],
+    author='Rumma & Ko Ltd',
+    author_email='info@lino-framework.org',
+    url="https://gitlab.com/lino-framework/atelier")
+
 install_requires = ['invoke', 'argh', 'six',
                     'future', 'Babel',
                     'python-dateutil', 'Sphinx', 'rstgen']
@@ -13,28 +22,26 @@ install_requires.append('sphinx-panels')
 install_requires.append('sphinx-rtd-theme')
 install_requires.append('pydata-sphinx-theme')
 install_requires.append('insipid-sphinx-theme')
+install_requires.append('gitpython')
+
 # trying to fix #3246
-tests_require = ['gitpython', 'pytest-cov']
+tests_require = ['pytest-cov']
 
-# Explicitly install `importlib` under Python 2.6. Thanks to
-# https://stackoverflow.com/questions/9418064
-try:
-    import importlib
-except ImportError:
-    install_requires.append('importlib')
+# # Explicitly install `importlib` under Python 2.6. Thanks to
+# # https://stackoverflow.com/questions/9418064
+# try:
+#     import importlib
+# except ImportError:
+#     install_requires.append('importlib')
 
-SETUP_INFO = dict(
-    name='atelier',
-    version='1.1.31',
+SETUP_INFO.update(
     install_requires=install_requires,
     tests_require=tests_require,
-    scripts=['scripts/per_project'],
-    description="A collection of tools for software artists",
-    license_files=['COPYING'],
+    # scripts=['scripts/per_project'],
+    entry_points={
+        'console_scripts': ['per_project = atelier.cli.per_project:main']
+    },
     test_suite='tests',
-    author='Luc Saffre',
-    author_email='luc@lino-framework.org',
-    url="https://gitlab.com/lino-framework/atelier",
     long_description="""\
 
 `atelier` is a collection of tools for managing and maintaining Python software
@@ -68,15 +75,18 @@ SETUP_INFO.update(packages=[n for n in """
 atelier
 atelier.sphinxconf
 atelier.invlib
+atelier.cli
 """.splitlines() if n])
 
-SETUP_INFO.update(package_data=dict())
+SETUP_INFO.update(
+    zip_safe=False,
+    include_package_data=True)
 
-
-def add_package_data(package, *patterns):
-    l = SETUP_INFO['package_data'].setdefault(package, [])
-    l.extend(patterns)
-    return l
-
-
-add_package_data('atelier.sphinxconf', '*.html')
+# SETUP_INFO.update(package_data=dict())
+#
+# def add_package_data(package, *patterns):
+#     l = SETUP_INFO['package_data'].setdefault(package, [])
+#     l.extend(patterns)
+#     return l
+#
+# add_package_data('atelier.sphinxconf', '*.html')
