@@ -25,6 +25,7 @@ the documentation trees maintained by us.
 import logging ; logger = logging.getLogger(__name__)
 
 import sys
+import os
 
 from pathlib import Path
 from pkg_resources import parse_version
@@ -32,7 +33,7 @@ import sphinx
 import atelier
 from atelier.projects import get_project_from_path
 
-def configure(globals_dict):
+def configure(globals_dict, project=None, conffiles=["default_conf.py"]):
     """
     Adds to your `conf.py` an arbitrary series of things that all our
     Sphinx docs configuration files have in common.
@@ -57,23 +58,34 @@ def configure(globals_dict):
     """
     docs_root = Path(globals_dict['__file__']).parent.absolute()
     sys.path.append(docs_root)
-    atelier.current_project = get_project_from_path(docs_root.parent)
-    atelier.current_project.load_info()
 
-    globals_dict.setdefault('html_context', dict()).update(
-        SETUP_INFO=atelier.current_project.SETUP_INFO)
-
-    version = atelier.current_project.SETUP_INFO.get('version', None)
-    if version:
-        globals_dict.update(release=version)
-        globals_dict.update(version='.'.join(version.split('.')[:2]))
+    # https://insipid-sphinx-theme.readthedocs.io/en/0.2.0/configuration.html
+    globals_dict.setdefault('html_theme', "insipid")
+    # globals_dict.setdefault('html_theme', "pydata_sphinx_theme")
+    # globals_dict.update(html_theme="bizstyle")
 
     globals_dict.setdefault('extlinks', dict())
     globals_dict.setdefault('intersphinx_mapping', dict())
     globals_dict.update(exclude_patterns=['old', 'include', 'shared', '.build'])
-    globals_dict.update(extensions=[
-        'sphinx.ext.autodoc',
-        'sphinx.ext.autosummary',
+    extensions = []
+    globals_dict.update(extensions=extensions)
+
+    if project is None:
+        project = get_project_from_path(docs_root.parent)
+    atelier.current_project = project
+    project.load_info()
+    globals_dict.setdefault('html_context', dict()).update(
+        SETUP_INFO=project.SETUP_INFO)
+
+    version = project.SETUP_INFO.get('version', None)
+    if version:
+        globals_dict.update(release=version)
+        globals_dict.update(version='.'.join(version.split('.')[:2]))
+
+    if 'name' in project.SETUP_INFO:
+        extensions += ['sphinx.ext.autodoc', 'sphinx.ext.autosummary']
+        
+    extensions += [
         'sphinx.ext.inheritance_diagram',
         'sphinx.ext.todo',
         'sphinx.ext.extlinks',
@@ -86,7 +98,7 @@ def configure(globals_dict):
         'atelier.sphinxconf.dirtables',
         'atelier.sphinxconf.refstothis',
         'atelier.sphinxconf.insert_input',
-    ])
+    ]
 
     # default config for autosummary:
     globals_dict.update(autosummary_generate=True)
@@ -103,7 +115,7 @@ def configure(globals_dict):
     # tp += ['.templates', str(mydir)]
     tp.append(str(mydir / 'templates'))
 
-    globals_dict.setdefault('html_static_path', [])
+    globals_dict.setdefault('html_static_path', [str(mydir / 'static')])
 
     # Some settings I use in all projects:
 
@@ -111,31 +123,14 @@ def configure(globals_dict):
     globals_dict.update(source_suffix='.rst')
     globals_dict.update(primary_domain='py')
     globals_dict.update(pygments_style='sphinx')
-
     globals_dict.update(autodoc_member_order='bysource')
     globals_dict.update(autodoc_inherit_docstrings=False)
 
-    if True:
-        # globals_dict.update(html_theme="bizstyle")
-        globals_dict.update(html_theme="sphinx_rtd_theme")
-        globals_dict.update(html_theme_options={
-            "prev_next_buttons_location": "both",
-            "style_nav_header_background": "#dddddd",
-            "style_external_links": False,  # disadvantage: line spacing increases for lines with a link
-            "includehidden": False,
-        })
-    else:
-        # use default html_theme ("alabaster")
-        globals_dict.update(html_theme="alabaster")
-        my_font_family = "Swiss, Helvetica, 'Liberation Sans'"
-        globals_dict.update(html_theme_options={
-            "font_family": my_font_family,
-            "head_font_family": my_font_family,
-        })
-
-    fn = mydir / 'default_conf.py'
-    with open(fn, "rb") as fd:
-        exec(compile(fd.read(), fn, 'exec'), globals_dict)
+    for fn in conffiles:
+        if not os.path.sep in fn:
+            fn = mydir / fn
+        with open(fn, "rb") as fd:
+            exec(compile(fd.read(), fn, 'exec'), globals_dict)
 
 def version2rst(self, m):
     """
