@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2011-2021 Rumma & Ko Ltd
+# Copyright 2011-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """
@@ -37,9 +37,11 @@ from docutils.parsers.rst import roles
 from sphinx.util.nodes import nested_parse_with_titles
 from sphinx.util.nodes import split_explicit_title
 from sphinx import addnodes
+from sphinx.util.docutils import SphinxRole
 
 from importlib import import_module
 from rstgen.utils import i2d, srcref, import_from_dotted_path, py2url_txt
+import atelier
 
 
 def autodoc_skip_member(app, what, name, obj, skip, options):
@@ -148,15 +150,16 @@ def autodoc_add_srcref(app, what, name, obj, options, lines):
             # admonitions when generating the summary: unfortunately
             # not.
             # 20151006 app.env.config.html_context.update(source_code_link=s)
-            if True:
-                lines += (SRCREF_TEMPLATE % s).splitlines()
-            else:
-                s = (SRCREF_TEMPLATE_BEFORE % s).splitlines()
-                # s = (SIDEBAR % s).splitlines()
-                s.reverse()
-                for ln in s:
-                    lines.insert(0, ln)
-                # print('\n'.join(lines))
+            if False: # 20220126 deactivate srcref mention (for Sphinx 4.4)
+                if True:
+                    lines += (SRCREF_TEMPLATE % s).splitlines()
+                else:
+                    s = (SRCREF_TEMPLATE_BEFORE % s).splitlines()
+                    # s = (SIDEBAR % s).splitlines()
+                    s.reverse()
+                    for ln in s:
+                        lines.insert(0, ln)
+                    # print('\n'.join(lines))
 
 
 def get_blog_url(env, today):
@@ -277,6 +280,31 @@ def command_parse(env, sig, signode):
     # signode += addnodes.literal_strong(sig, sig)  # needs Sphinx >= 1.3
     return sig
 
+# import re
+# from docutils.nodes import Node, TextElement, system_message
+from typing import TYPE_CHECKING, Any, Dict, List, Tuple, Type
+
+
+
+class CountRole(SphinxRole):
+    # amp_re = re.compile(r'(?<!&)&(?![&\s])')
+    counters = {}  # class attribute. same dict for all instances.
+
+    def run(self) -> Tuple[List[nodes.Node], List[nodes.system_message]]:
+        num = self.counters.get(self.rawtext, None)
+        if num is None:
+            num = self.counters[self.rawtext] = 1
+        else:
+            num += 1
+            self.counters[self.rawtext] = num
+        txt = self.format_number(num)
+        node = nodes.inline(rawtext=txt, classes=[self.name])
+        node += nodes.Text(txt)
+        return [node], []
+
+    def format_number(self, num):
+        return str(num)
+
 
 def html_page_context(app, pagename, templatename, context, doctree):
     # experimental. no result yet.
@@ -339,17 +367,21 @@ def setup(app):
     #     rolename='model', indextemplate='pair: %s; model')
     # app.connect('build-finished', handle_finished)
 
-    app.connect(str('autodoc-skip-member'), autodoc_skip_member)
-    app.connect(str('autodoc-process-docstring'), autodoc_add_srcref)
-    # app.connect(str('autodoc-process-signature'), process_signature)
-    app.connect(str('html-page-context'), html_page_context)
+    if 'name' in atelier.current_project.SETUP_INFO:
 
-    app.add_role(str('coderef'), coderef_role)
-    app.add_role(str('message'), message_role)
+        app.connect('autodoc-skip-member', autodoc_skip_member)
+        app.connect('autodoc-process-docstring', autodoc_add_srcref)
+    # app.connect(str('autodoc-process-signature'), process_signature)
+    app.connect('html-page-context', html_page_context)
+
+    app.add_role('coderef', coderef_role)
+    app.add_role('message', message_role)
 
     # 20210426 app.add_role(str('actor'), actor_role)
 
-    roles.register_canonical_role(str('blogref'), blogref_role)
+    roles.register_canonical_role('blogref', blogref_role)
+
+    roles.register_local_role('count', CountRole())
 
     app.add_config_value(
         'blogref_format',
